﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2012 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Encodings.SymbolicExpressionTreeEncoding {
  [Item("GeneticExchange", "Class that represents a genetic transaction (the exchange of genetic material between two individuals)")]
  [StorableClass]
  public class GeneticExchange : Item {
    [Storable]
    private IFragment inFragment;
    public IFragment FragmentIn {
      get { return inFragment; }
      set { inFragment = value; }
    }
    [Storable]
    private IFragment outFragment;
    public IFragment FragmentOut {
      get { return outFragment; }
      set { outFragment = value; }
    }

    [StorableConstructor]
    private GeneticExchange(bool serializing) : base(serializing) { }

    private GeneticExchange(GeneticExchange original, Cloner cloner)
      : base(original, cloner) {
      inFragment = (IFragment)original.inFragment.Clone();
      outFragment = (IFragment)original.outFragment.Clone();
    }
    public GeneticExchange() { }

    public override IDeepCloneable Clone(Cloner cloner) { return new GeneticExchange(this, cloner); }
  }
}